#ifndef	__LPTTEST_H
#define	__LPTTEST_H

//	PIC defines

/*
PIC 1   (Programmable Interrupt Controller 8259A)

0020   W  PIC initialization command word ICW1 (see #P006)
0020   W  PIC output control word OCW2 (see #P011)
0020   W  PIC output control word OCW3 (see #P012)
0020  R	  PIC  interrupt request/in-service registers after OCW3
		request register:
		 bit 7-0 = 0  no active request for the corresponding int. line
			 = 1  active request for corresponding interrupt line
		in-service register:
		 bit 7-0 = 0  corresponding line not currently being serviced
			 = 1  corresponding int. line currently being serviced

0021   W  PIC ICW2,ICW3,ICW4 immed after ICW1 to 0020 (see #P007,#P008,#P009)
0021  RW  PIC master interrupt mask register OCW1 (see #P010)

Bitfields for PIC initialization command word ICW1:
Bit(s)	Description	(Table P006)
 7-5	0 (only used in 8080/8085 mode)
 4	ICW1 is being issued
 3	(LTIM)
	=0  edge triggered mode
	=1  level triggered mode
 2	interrupt vector size
	=0 successive interrupt vectors use 8 bytes (8080/8085)
	=1 successive interrupt vectors use 4 bytes (80x86)
 1	(SNGL)
	=0  cascade mode
	=1  single mode, no ICW3 needed
 0	ICW4 needed
SeeAlso: #P007,#P008,#P009

Bitfields for PIC initialization command word ICW2:
Bit(s)	Description	(Table P007)
 7-3	address lines A0-A3 of base vector address for PIC
 2-0	reserved
SeeAlso: #P006,#P008,#P009

Bitfields for PIC initialization command word ICW3:
Bit(s)	Description	(Table P008)
 7-0	=0 slave controller not attached to corresponding interrupt pin
	=1 slave controller attached to corresponding interrupt pin
SeeAlso: #P006,#P007,#P009

Bitfields for PIC initialization command word ICW4:
Bit(s)	Description	(Table P009)
 7-5	reserved (0)
 4	running in special fully-nested mode
 3-2	mode
	0x nonbuffered mode
	10 buffered mode/slave
	11 buffered mode/master
 1	Auto EOI
 0	=0  8085 mode
	=1  8086/8088 mode
SeeAlso: #P006,#P007,#P008

Bitfields for PIC output control word OCW1:
Bit(s)	Description	(Table P010)
 7	disable IRQ7 (parallel printer interrupt)
 6	disable IRQ6 (diskette interrupt)
 5	disable IRQ5 (fixed disk interrupt)
 4	disable IRQ4 (serial port 1 interrupt)
 3	disable IRQ3 (serial port 2 interrupt)
 2	disable IRQ2 (video interrupt)
 1	disable IRQ1 (keyboard, mouse, RTC interrupt)
 0	disable IRQ0 (timer interrupt)
SeeAlso: #P011,#P012,#P058

Bitfields for PIC output control word OCW2:
Bit(s)	Description	(Table P011)
 7-5	operation
	000 rotate in auto EOI mode (clear)
	001 (WORD_A) nonspecific EOI
	010 (WORD_H) no operation
	011 (WORD_B) specific EOI
	100 (WORD_F) rotate in auto EOI mode (set)
	101 (WORD_C) rotate on nonspecific EOI command
	110 (WORD_E) set priority command
	111 (WORD_D) rotate on specific EOI command
 4	reserved (0)
 3	reserved (0)
 2-0	interrupt request to which the command applies
	(only used by WORD_B, WORD_D, and WORD_E)
SeeAlso: #P010,#P012

Bitfields for PIC output control word OCW3:
Bit(s)	Description	(Table P012)
 7	reserved (0)
 6-5	special mask
	0x  no operation
	10  reset special mask
	11  set special mask
 4	reserved (0)
 3	reserved (1)
 2	poll command
 1-0	function
	0x  no operation
	10  read interrupt request register on next read from port 0020
	11  read interrupt in-service register on next read from port 0020
SeeAlso: #P010,#P011
*/
#include	<dos.h>

/* Legge  l'Interrupt Mask Reg.  */
#define R_IMR     inportb(0x21)

/* Scrive l'Interrupt Mask Reg.  */
#define W_IMR(D)  outportb(0x21,D)

/* Legge l'Interrupt Request Reg.*/
#define R_IRR 	  (outportb(0x20,0x0a),inportb(0x20))

/* Legge l'Interrupt Status  Reg.*/
#define R_ISR 	  (outportb(0x20,0x0b),inportb(0x20))

/* End Of Interrupt x 8259A		 */
#define EOI		  outportb(0x20,0x20)

/* Disabilito l'interrupt della scheda PC_COM */
#define DISABLE_IRQ(irq)		(W_IMR(R_IMR |   (1 << (irq))))

/* Abilito l'interrupt della scheda PC_COM */
#define ENABLE_IRQ(irq)	(W_IMR(R_IMR & (~(1 << (irq)))))

//	PAR defines

#define	PC_PAR_LPT_CTR_O_STROBE    	0
#define	PC_PAR_LPT_CTR_AUTOFEED  	1
#define	PC_PAR_LPT_CTR_INIT      	2
#define	PC_PAR_LPT_CTR_SEL_OUT    	3
#define	PC_PAR_LPT_CTR_ENIRQ	  	4
#define	PC_PAR_LPT_CTR_DIR	  		5

// Bit nel registro di stato

#define	PC_PAR_LPT_ST_ERROR     	3
#define	PC_PAR_LPT_ST_SEL_IN     	4
#define	PC_PAR_LPT_ST_PEND      	5
#define	PC_PAR_LPT_ST_ACK       	6
#define	PC_PAR_LPT_ST_BUSY     		7

#define	IRQ_VECT0					8
#define	IRQ_VECT1					9
#define	IRQ_VECT2					10
#define	IRQ_VECT3					11
#define	IRQ_VECT4					12
#define	IRQ_VECT5					13
#define	IRQ_VECT6					14
#define	IRQ_VECT7					15

#define	IRQ_0					0
#define	IRQ_1					1
#define	IRQ_2					2
#define	IRQ_3					3
#define	IRQ_4					4
#define	IRQ_5					5
#define	IRQ_6					6
#define	IRQ_7					7


//	Typedefs

typedef unsigned char  byte;
typedef unsigned short word;
typedef enum Action 	{ None, ListPorts , QueryMask, TestPorts };
typedef	enum TestMode   { OneShot = 0x01, Continuosly = 0x02, LoopBack = 0x04, OutMode = 0x08 };
typedef	enum PortMode   { NibbleMode, ByteMode };

typedef	enum bool		{ false, true };


#endif	//	__LPTTEST_H